# PyGlicko2

![PyPI - Version](https://img.shields.io/pypi/v/pyglicko2)
![PyPI - License](https://img.shields.io/pypi/l/pyglicko2)

Python implementation of the Glicko-2 system

## Installing with pip

To install PyGlicko2 using pip, run the following command:
```
pip install pyglicko2
```

## Contributing

PyGlicko2 is in an early development stage, so we welcome help from you guys :)

### Building from source

To build PyGlicko2 from source, clone PyGlicko2's Github repository using `git`:
```
git clone https://github.com/cyan-ice/pyglicko2.git
```
Then, in the `pyglicko2` repository you just cloned, execute the following command:
```
pip install dist/pyglicko2-*-py3-none-any.whl
```
Where `*` is the latest version of PyGlicko2.

### Testing

To execute all tests, run
```
python test.py
```
In the current directory.

You should see something like this:
```
Test #1: Passed in 0.000s
Passed 1/1
```

### Documentation

We don't have a real documentation for PyGlicko2 at the moment, please contact [@cyan-ice](https://github.com/cyan-ice) if you have any interest in contributing to our docs.